==> ejc-ztpcct-impl-3.0.0-20240725.075727-173-sources.jar: com/ejianc/design/vo/DesignDocumentVO.java <==
package com.ejianc.design.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 设计管理设计文件表
 * 
 * @author generator
 * 
 */
public class DesignDocumentVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    private Long projectId; // 项目ID
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private Long orgId; // 项目组织ID
    private String orgCode; // 项目组织编码
    private String orgName; // 项目组织名称
    private Long parentOrgId; // 父级组织ID
    private String parentOrgCode; // 父级组织编码
    private String parentOrgName; // 父级组织名称
    private String billCode; // 文件编码
    private String fileName; // 文件名称
    private Long engineeringTypeId; // 工程类别
    private String area; // 地区
    private String areaName; // 地区
    private String address; // 地址
    private String constructName; // 建设单位
    private String supervisor; // 监理单位
    private String designer; // 编制单位
    private String textAttachment; // 正文附件
    private Long textAttachmentId; // 正文附件id
    private String createUserName; // 创建人名称
    private Long submitType; // 文件报审类型
    private Long fileType; // 文件分类
    private Long constructId; // 建设单位id
    private Long contractManager;//epc总承包中心负责人

    private List<DesignOpinionInfoVO> opinionInfoList; // 意见栏


    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode = "project-set")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }
    @ReferDeserialTransfer
    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }
    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
    public String getAreaName() {
        return areaName;
    }

    public void setAreaName(String areaName) {
        this.areaName = areaName;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public String getConstructName() {
        return constructName;
    }

    public void setConstructName(String constructName) {
        this.constructName = constructName;
    }
    public String getSupervisor() {
        return supervisor;
    }

    public void setSupervisor(String supervisor) {
        this.supervisor = supervisor;
    }
    public String getDesigner() {
        return designer;
    }

    public void setDesigner(String designer) {
        this.designer = designer;
    }
    public String getTextAttachment() {
        return textAttachment;
    }

    public void setTextAttachment(String textAttachment) {
        this.textAttachment = textAttachment;
    }
    public Long getTextAttachmentId() {
        return textAttachmentId;
    }

    public void setTextAttachmentId(Long textAttachmentId) {
        this.textAttachmentId = textAttachmentId;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getSubmitType() {
        return submitType;
    }
    @ReferDeserialTransfer
    public void setSubmitType(Long submitType) {
        this.submitType = submitType;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getFileType() {
        return fileType;
    }
    @ReferDeserialTransfer
    public void setFileType(Long fileType) {
        this.fileType = fileType;
    }

    public List<DesignOpinionInfoVO> getOpinionInfoList() {
        return opinionInfoList;
    }

    public void setOpinionInfoList(List<DesignOpinionInfoVO> opinionInfoList) {
        this.opinionInfoList = opinionInfoList;
    }

    @ReferSerialTransfer(referCode="support-customer,support-supplier")
    public Long getConstructId() {
        return constructId;
    }
    @ReferDeserialTransfer
    public void setConstructId(Long constructId) {
        this.constructId = constructId;
    }

    @ReferSerialTransfer(referCode="idm-employee")
    public Long getContractManager() {
        return contractManager;
    }
    @ReferDeserialTransfer
    public void setContractManager(Long contractManager) {
        this.contractManager = contractManager;
    }
}

==> ejc-ztpcct-impl-3.0.0-20251204.064048-220-sources.jar: com/ejianc/design/vo/DesignDocumentVO.java <==
package com.ejianc.design.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 设计管理设计文件表
 * 
 * @author generator
 * 
 */
public class DesignDocumentVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    private Long projectId; // 项目ID
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private Long orgId; // 项目组织ID
    private String orgCode; // 项目组织编码
    private String orgName; // 项目组织名称
    private Long parentOrgId; // 父级组织ID
    private String parentOrgCode; // 父级组织编码
    private String parentOrgName; // 父级组织名称
    private String billCode; // 文件编码
    private String fileName; // 文件名称
    private Long engineeringTypeId; // 工程类别
    private String area; // 地区
    private String areaName; // 地区
    private String address; // 地址
    private String constructName; // 建设单位
    private String supervisor; // 监理单位
    private String designer; // 编制单位
    private String textAttachment; // 正文附件
    private Long textAttachmentId; // 正文附件id
    private String createUserName; // 创建人名称
    private Long submitType; // 文件报审类型
    private Long fileType; // 文件分类
    private Long constructId; // 建设单位id
    private Long contractManager;//epc总承包中心负责人
    private Integer haveOpinion;//是否有意见:1 是 0 否

    private List<DesignOpinionInfoVO> opinionInfoList; // 意见栏


    public Integer getHaveOpinion() {
        return haveOpinion;
    }

    public void setHaveOpinion(Integer haveOpinion) {
        this.haveOpinion = haveOpinion;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode = "project-set")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }
    @ReferDeserialTransfer
    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }
    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
    public String getAreaName() {
        return areaName;
    }

    public void setAreaName(String areaName) {
        this.areaName = areaName;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public String getConstructName() {
        return constructName;
    }

    public void setConstructName(String constructName) {
        this.constructName = constructName;
    }
    public String getSupervisor() {
        return supervisor;
    }

    public void setSupervisor(String supervisor) {
        this.supervisor = supervisor;
    }
    public String getDesigner() {
        return designer;
    }

    public void setDesigner(String designer) {
        this.designer = designer;
    }
    public String getTextAttachment() {
        return textAttachment;
    }

    public void setTextAttachment(String textAttachment) {
        this.textAttachment = textAttachment;
    }
    public Long getTextAttachmentId() {
        return textAttachmentId;
    }

    public void setTextAttachmentId(Long textAttachmentId) {
        this.textAttachmentId = textAttachmentId;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getSubmitType() {
        return submitType;
    }
    @ReferDeserialTransfer
    public void setSubmitType(Long submitType) {
        this.submitType = submitType;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getFileType() {
        return fileType;
    }
    @ReferDeserialTransfer
    public void setFileType(Long fileType) {
        this.fileType = fileType;
    }

    public List<DesignOpinionInfoVO> getOpinionInfoList() {
        return opinionInfoList;
    }

    public void setOpinionInfoList(List<DesignOpinionInfoVO> opinionInfoList) {
        this.opinionInfoList = opinionInfoList;
    }

    @ReferSerialTransfer(referCode="support-customer,support-supplier")
    public Long getConstructId() {
        return constructId;
    }
    @ReferDeserialTransfer
    public void setConstructId(Long constructId) {
        this.constructId = constructId;
    }

    @ReferSerialTransfer(referCode="idm-employee")
    public Long getContractManager() {
        return contractManager;
    }
    @ReferDeserialTransfer
    public void setContractManager(Long contractManager) {
        this.contractManager = contractManager;
    }
}
